/* 

   Test program for rotfrm.
 
   Given the vector (0,0,1) in the INFRAM,
   compute the vector in the new frame.

   Given the vector to the reference object in the 
   INFRAM, computer the vector components in the new frame.

   ---Jeff Bytof 

*/

#include "SpiceUsr.h"
#include "SpiceZmc.h"
#include "SpiceEll.h"

int main()
{

   SpiceBoolean    found;

   SpiceChar       infram [10];
   SpiceChar       type   [3];

   SpiceDouble     et;
   SpiceDouble     lt; 
   SpiceDouble     mat    [3][3];
   SpiceDouble     north  [3];
   SpiceDouble     state  [3];
   SpiceDouble     toref  [3];
   SpiceDouble     toref2 [3];
   SpiceDouble     z      [] = { 0.0, 0.0, 1.0 };
   SpiceDouble     z2     [3]; 

   SpiceInt        cenid;
   SpiceInt        i;
   SpiceInt        ier;
   SpiceInt        j;
   SpiceInt        refid;


   furnsh_c ( "trotfrm.ker" );

   printf( "enter central body ID:\n" );
   scanf( "%d", &cenid );
   
   printf( "enter reference body ID:\n" );
   scanf( "%d", &refid );

   printf( "enter initial frame name:\n" );
   scanf( "%s", infram );
    
   printf( "enter frame et in seconds from J2000\n" );
   scanf( "%f", &et );

   printf( "enter output frame type:\n" );
   printf( "equatorial - equ\n" );
   printf( "orbital    - orb\n" );
   scanf( "%s", type );


   rotfrm ( cenid, refid, infram, et, type, mat, &found, &ier ); 


   printf( "---------------- test case --------------\n" );
   printf( "cenid = %d\n", cenid );
   printf( "refid = %d\n", refid );
   printf( "et    = %f\n", et    );
   printf( "type  = %s\n", type  );
   
   if ( found == SPICETRUE ) {

      printf ( "\n" );
      printf ( "output matrix from rotfrm:\n" );

      for ( i=0; i<3; i++ ) {
         for ( j=0; j<3; j++ ) {
            printf("%f ", mat[i][j] );
         }
         printf("\n");
      }

/*
   Get vector to reference body in INFRAM, then rotate to new frame. 
*/
 
      mxv_c ( mat, z, north ); 
    
      printf( "\n" );
      printf( "convert from frame=%s to body=%d refid=%d frame type=%s\n", 
              infram, cenid, refid, type);
      printf( "vin  = %f %f %f\n", z[0], z[1], z[2] );
      printf( "vout = %f %f %f\n", north[0], north[1], north[2] );

      printf("angle(vin-vout) = %f \n", dpr_c()*vsep_c(z,north));
      printf("90-angle(vin-vout) = %f \n", 90.0-dpr_c()*vsep_c(z,north));


/*
    Get vector to secondary reference in INFRAM, then rotate to new frame.
*/

      spkez_c ( refid, et, infram, "LT+S", cenid, state, &lt );
      vpack_c ( state[0], state[1], state[2], toref ); 
      vhat_c  ( toref,    toref );

      printf( "v to refid = %f %f %f (%s)\n", 
              toref[0], toref[1], toref[2], infram);
      mxv_c ( mat, toref, toref2 );
      printf( "v to refid2 = %f %f %f (%d, %d, %s)\n", 
               toref2[0], toref2[1], toref2[2], cenid, refid, type);
      

   } else {

      printf( "trotfrm: matrix not found\n" );
      printf( "ier = %d\n", ier );
 
   }

   printf("\n");

   exit(0);

}
